(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 9.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[     18539,        558]
NotebookOptionsPosition[     14446,        443]
NotebookOutlinePosition[     16969,        507]
CellTagsIndexPosition[     16891,        502]
WindowTitle->Automatic
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " as end-user application"
}], "Subsection",
 CellChangeTimes->{{3.571894141321701*^9, 3.5718941509622526`*^9}, {
  3.571894349292597*^9, 3.571894372169905*^9}, {3.5718944908196917`*^9, 
  3.5718944940358753`*^9}, {3.571895663726637*^9, 3.571895665541741*^9}, {
  3.571902998083138*^9, 3.5719030010633087`*^9}, {3.5719454015253487`*^9, 
  3.571945404985546*^9}}],

Cell[TextData[{
 "Starting from version 6, ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " has introduced a new way to interact with calculations and data: dynamic \
and interactive constructs and interfaces. This has been the most relevant \
innovation in the ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " front end history. Now we can directly interact with calculations and/or \
data underlying our mathematical models. "
}], "Text",
 CellChangeTimes->{{3.5718952704982405`*^9, 3.571895378062298*^9}, {
   3.5718954537646275`*^9, 3.571895478336033*^9}, {3.571895616064911*^9, 
   3.571895678779498*^9}, 3.5719030251886883`*^9, {3.571943826274249*^9, 
   3.571943876277109*^9}, {3.5719439702954865`*^9, 3.571944035489216*^9}}],

Cell[TextData[{
 "The basic idea is that using the Dynamic wrapper we can create dynamic \
instances of any kind of ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " expression. This means that if someone (the kernel or the user by means of \
controls) changes the values upon which that expression depends, the \
expression will be updated automatically."
}], "Text",
 CellChangeTimes->{{3.5719672348105793`*^9, 3.5719673142041206`*^9}, {
  3.571967366908135*^9, 3.5719673700493145`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"Slider", "[", 
    RowBox[{"Dynamic", "[", "x", "]"}], "]"}], ",", 
   RowBox[{"Dynamic", "[", "x", "]"}]}], "}"}]], "Input",
 CellChangeTimes->{{3.571967105824202*^9, 3.5719671359549255`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"PopupMenu", "[", 
    RowBox[{
     RowBox[{"Dynamic", "[", "x", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "2", ",", "3"}], "}"}]}], "]"}], ",", 
   RowBox[{"Dynamic", "[", "x", "]"}]}], "}"}]], "Input",
 CellChangeTimes->{{3.5719671519878426`*^9, 3.5719671914721003`*^9}}],

Cell["\<\
Even for the interface building there is a macro-function called Manipulate.\
\>", "Text",
 CellChangeTimes->{{3.5719673802568984`*^9, 3.5719674147458715`*^9}, {
  3.571967468101923*^9, 3.5719675044590025`*^9}, {3.571967669544445*^9, 
  3.5719676935018153`*^9}}],

Cell["\<\
Suppose we want to know how changes the value of a given calculation when a \
parameter in the original expression changes. For instance the following \
integral\
\>", "Text",
 CellChangeTimes->{{3.5719673802568984`*^9, 3.5719674147458715`*^9}, {
  3.571967468101923*^9, 3.5719675044590025`*^9}, {3.571967669544445*^9, 
  3.5719676965669904`*^9}}],

Cell[BoxData[
 RowBox[{"Integrate", "[", 
  RowBox[{
   RowBox[{"1", "/", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"x", "^", "3"}], "+", "1"}], ")"}]}], ",", "x"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.571967223118911*^9, 3.571967226633112*^9}, {
   3.571967417557032*^9, 3.5719674186720953`*^9}, 3.5719674496858697`*^9}],

Cell["\<\
We can replace the coefficient with a parameter, and then ask a loop-cycle to \
enumarate all results changing the value of the parameter \
\>", "Text",
 CellChangeTimes->{{3.571967510132327*^9, 3.5719675516697025`*^9}}],

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"Integrate", "[", 
    RowBox[{
     RowBox[{"1", "/", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"x", "^", "n"}], "+", "1"}], ")"}]}], ",", "x"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"n", ",", "1", ",", "10", ",", "1"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.571967223118911*^9, 3.571967226633112*^9}, {
   3.571967417557032*^9, 3.5719674186720953`*^9}, 3.5719674496858697`*^9, {
   3.5719675532977962`*^9, 3.5719675683486567`*^9}}],

Cell["\<\
This solution has two main drawback: the time that we have to wait before to \
see the results, the way that such results are organised and shown.\
\>", "Text",
 CellChangeTimes->{{3.571967570956806*^9, 3.57196761717645*^9}, 
   3.5719676541165624`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Example 1", "Subsubsection",
 CellChangeTimes->{{3.5719441477016335`*^9, 3.5719441495107374`*^9}}],

Cell["A manual data fitting", "Text",
 CellChangeTimes->{{3.5719441530099373`*^9, 3.571944164581599*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"data", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{
        RowBox[{"2.5", 
         RowBox[{"x", "^", "2"}]}], "-", 
        RowBox[{"8", "x"}], "+", "1.87", "+", 
        RowBox[{"RandomReal", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "1"}], ",", "1"}], "}"}], "]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "2"}], ",", "5", ",", "0.05"}], "}"}]}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Show", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"ListPlot", "[", "data", "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"a", " ", 
         RowBox[{"x", "^", "2"}]}], "+", 
        RowBox[{"b", " ", "x"}], "+", "c"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"-", "2"}], ",", "5"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Thick", ",", "Red"}], "}"}]}]}], "]"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "5"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "40"}], ",", "40"}], "}"}]}], "}"}]}]}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{"a", ",", 
     RowBox[{"-", "10"}], ",", "10"}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{"b", ",", 
     RowBox[{"-", "10"}], ",", "10"}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{"c", ",", 
     RowBox[{"-", "10"}], ",", "10"}], "}"}]}], "]"}]}], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.4495839256789837`*^9, 3.449584051134583*^9}, 
   3.524887359390625*^9, {3.5279233678812733`*^9, 3.5279233684272747`*^9}, 
   3.5284314676734285`*^9, {3.5719441693958745`*^9, 3.5719441965844297`*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Example 2", "Subsubsection",
 CellChangeTimes->{{3.5719442201667786`*^9, 3.5719442235429716`*^9}}],

Cell["\<\
A manual interpolating polynomial\
\>", "Text",
 CellChangeTimes->{{3.571944232012456*^9, 3.57194423785279*^9}}],

Cell[BoxData[
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Column", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"TraditionalForm", "[", 
       RowBox[{"Expand", "[", 
        RowBox[{"InterpolatingPolynomial", "[", 
         RowBox[{"pts", ",", "x"}], "]"}], "]"}], "]"}], ",", 
      RowBox[{"Plot", "[", 
       RowBox[{
        RowBox[{"InterpolatingPolynomial", "[", 
         RowBox[{"pts", ",", "x"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"x", ",", 
          RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
        RowBox[{"PlotRange", "\[Rule]", " ", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "10"}], ",", "10"}], "}"}]}], "}"}]}], ",", 
        RowBox[{"Filling", "\[Rule]", "Axis"}], ",", 
        RowBox[{"FillingStyle", "\[Rule]", "LightGreen"}], ",", 
        RowBox[{"ImageSize", "\[Rule]", "600"}]}], "]"}]}], "}"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"pts", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "0.25"}], ",", "0.86"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0.53", ",", "0.08"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0.97", ",", "0.73"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0.12", ",", "0.10"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0.78", ",", "0.52"}], "}"}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "10"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "10"}], "}"}], ",", "Locator", ",", 
     RowBox[{"LocatorAutoCreate", "\[Rule]", "True"}]}], "}"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.5719443964238596`*^9, 3.571944433084957*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Example 3", "Subsubsection",
 CellChangeTimes->{{3.571944370100354*^9, 3.571944376876742*^9}}],

Cell["A dynamic texture", "Text",
 CellChangeTimes->{{3.571944456605302*^9, 3.5719444611935644`*^9}}],

Cell[BoxData[
 RowBox[{"Dynamic", "[", 
  RowBox[{"ClockGauge", "[", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.571944473040242*^9, 3.5719444773884907`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"vtc", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1"}], "}"}]}], "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"coords", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "0", ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1", ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "0", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"1", ",", "1", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "1", ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "1", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "0", ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1", ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "1", ",", "1"}], "}"}]}], "}"}]}], "}"}]}], 
  ";"}], "\n", 
 RowBox[{"Dynamic", "[", 
  RowBox[{"Graphics3D", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Dynamic", "[", 
       RowBox[{
        RowBox[{"Texture", "[", 
         RowBox[{"ClockGauge", "[", "]"}], "]"}], ",", 
        RowBox[{"UpdateInterval", "\[Rule]", "1"}]}], "]"}], ",", 
      RowBox[{"Polygon", "[", 
       RowBox[{"coords", ",", 
        RowBox[{"VertexTextureCoordinates", "\[Rule]", 
         RowBox[{"Table", "[", 
          RowBox[{"vtc", ",", 
           RowBox[{"{", "6", "}"}]}], "]"}]}]}], "]"}]}], "}"}], ",", 
    RowBox[{"Lighting", "\[Rule]", "\"\<Neutral\>\""}], ",", 
    RowBox[{"Boxed", "\[Rule]", "False"}]}], "]"}], "]"}]}], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Example 4", "Subsubsection",
 CellChangeTimes->{{3.571944515942696*^9, 3.5719445197479134`*^9}}],

Cell[TextData[{
 "All the Thanks to these new interface functionalities, we can use develop, \
and use, ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " application with such graphical user interfaces (GUIs) that don\
\[CloseCurlyQuote]t require any ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " syntax knowledge to the end user.\n",
 ButtonBox["Example 4.1",
  BaseStyle->"Hyperlink",
  ButtonData->{"StyleSheeCreatorPalette.nb", None}],
 "\n",
 ButtonBox["Example 4.2",
  BaseStyle->"Hyperlink",
  ButtonData->{"WebAdDashboard.cdf", None}]
}], "Text",
 CellChangeTimes->{{3.5719445247581997`*^9, 3.571944526043274*^9}, {
  3.571944558050104*^9, 3.5719446527115183`*^9}, {3.5719447469559093`*^9, 
  3.5719447559894257`*^9}}]
}, Open  ]]
}, Open  ]]
},
ScreenStyleEnvironment->"SlideShow",
WindowSize->{1424, 775},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
WindowTitle->Automatic,
ShowSelection->True,
TaggingRules->{"SlideShow" -> True},
ShowPredictiveInterface->True,
Background->Automatic,
FrontEndVersion->"9.0 for Microsoft Windows (64-bit) (January 25, 2013)",
StyleDefinitions->Notebook[{
   Cell[
    StyleData[StyleDefinitions -> "Default.nb"]], 
   Cell[
    CellGroupData[{
      Cell[
       StyleData["Didascalia", StyleDefinitions -> StyleData["Text"]], 
       CellMargins -> {{Inherited, Inherited}, {20, 0}}, ReturnCreatesNewCell -> 
       True, StyleKeyMapping -> {"Tab" -> "SubitemNumbered"}, TextAlignment -> 
       Center, CounterIncrements -> "Figura", MenuSortingValue -> 1630, 
       FontFamily -> "Arial", FontSize -> 11], 
      Cell[
       StyleData["Didascalia", "SlideShow"], 
       CellMargins -> {{Inherited, Inherited}, {20, 0}}, ReturnCreatesNewCell -> 
       True, StyleKeyMapping -> {"Tab" -> "SubitemNumbered"}, TextAlignment -> 
       Center, CounterIncrements -> "Figura", MenuSortingValue -> 1630, 
       FontFamily -> "Arial", FontSize -> 11]}, Open]], 
   Cell[
    StyleData["Figura"], CellMargins -> {{0, 0}, {0, 0}}, 
    ReturnCreatesNewCell -> True, 
    StyleKeyMapping -> {"Tab" -> "SubitemNumbered"}, 
    CellFrameMargins -> {{0, 0}, {5, 0}}, TextAlignment -> Center, 
    LineSpacing -> {1, 1}, MenuSortingValue -> 1630, FontFamily -> "Arial"], 
   Cell[
    StyleData["Figura"], CellMargins -> {{Inherited, Inherited}, {5, 0}}, 
    ReturnCreatesNewCell -> True, 
    StyleKeyMapping -> {"Tab" -> "SubitemNumbered"}, TextAlignment -> Center, 
    MenuSortingValue -> 1630, FontFamily -> "Arial"]}, Visible -> False, 
  FrontEndVersion -> "9.0 for Microsoft Windows (64-bit) (January 25, 2013)", 
  StyleDefinitions -> "PrivateStylesheetFormatting.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "SlideShowHeader"->{
  Cell[602, 23, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[4993, 146, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[7417, 221, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[9747, 294, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[13484, 411, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"SlideShowHeader", 16433, 488}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[602, 23, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[691, 28, 428, 9, 84, "Subsection"],
Cell[1122, 39, 744, 15, 107, "Text"],
Cell[1869, 56, 494, 10, 106, "Text"],
Cell[2366, 68, 245, 6, 46, "Input"],
Cell[2614, 76, 339, 9, 46, "Input"],
Cell[2956, 87, 272, 5, 45, "Text"],
Cell[3231, 94, 357, 7, 75, "Text"],
Cell[3591, 103, 332, 9, 46, "Input"],
Cell[3926, 114, 230, 4, 75, "Text"],
Cell[4159, 120, 519, 13, 46, "Input"],
Cell[4681, 135, 263, 5, 75, "Text"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[4993, 146, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[5082, 151, 104, 1, 50, "Subsubsection"],
Cell[5189, 154, 105, 1, 45, "Text"],
Cell[5297, 157, 2071, 58, 250, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[7417, 221, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[7506, 226, 104, 1, 50, "Subsubsection"],
Cell[7613, 229, 122, 3, 45, "Text"],
Cell[7738, 234, 1960, 54, 192, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[9747, 294, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[9836, 299, 100, 1, 50, "Subsubsection"],
Cell[9939, 302, 101, 1, 45, "Text"],
Cell[10043, 305, 160, 3, 46, "Input"],
Cell[10206, 310, 3229, 95, 192, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[13484, 411, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[13573, 416, 102, 1, 50, "Subsubsection"],
Cell[13678, 419, 740, 20, 137, "Text"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
