(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 9.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[     21830,        697]
NotebookOptionsPosition[     18718,        598]
NotebookOutlinePosition[     19592,        628]
CellTagsIndexPosition[     19514,        623]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " as a powerful pocket calculator"
}], "Subsection",
 CellChangeTimes->{
  3.5677576479117575`*^9, {3.56775769201528*^9, 3.567757695118458*^9}, 
   3.567779814134672*^9, {3.5677804469578676`*^9, 3.5677804508440895`*^9}, 
   3.5677823057721853`*^9, 3.56782322662325*^9, {3.5718961387628074`*^9, 
   3.571896154354699*^9}, {3.5718966008042345`*^9, 3.571896612203887*^9}, 
   3.5719453832313023`*^9}],

Cell[TextData[{
 "When working with ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " you should consider that the system is able to solve problems rathen than \
just do calculations. \nJust to make an example, to solve a system of \
differential equations can involve many different issues related to the \
solution methods, class of equation provided, initial conditions, existing or \
not of analitical/numerical method and their computation complexity or \
robustness, etc. Similar issues arise when working with integrals, limits, \
sums, equation solving, and almost any complex calculation task.\nThanks to \
the ",
 ButtonBox["Automatic Algorithms Selection",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www.wolfram.com/technology/guide/AutomaticAlgorithmSelection/\
"], None},
  ButtonNote->
   "http://www.wolfram.com/technology/guide/AutomaticAlgorithmSelection/"],
 " mechanism, ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " simplify all such steps in just one macro (for that also called ",
 ButtonBox["Task-oriented superfunction",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www.wolfram.com/technology/guide/TaskOrientedSuperfunctions/"]\
, None},
  ButtonNote->
   "http://www.wolfram.com/technology/guide/TaskOrientedSuperfunctions/"],
 "), embedding all the solution methods, normally selected automatically by \
the function itself after a pre-processing and evaluation of the given task \
and arguments.  "
}], "Text",
 CellChangeTimes->{{3.5677806191887183`*^9, 3.5677806366117153`*^9}, {
  3.5677807072677565`*^9, 3.567780713228097*^9}, {3.567780790462515*^9, 
  3.5677808771804748`*^9}, {3.567782032005527*^9, 3.5677820489084935`*^9}, {
  3.567782110494016*^9, 3.567782157555708*^9}, {3.5718961618431273`*^9, 
  3.571896434929747*^9}, {3.5718964905299273`*^9, 3.5718965701654825`*^9}, {
  3.5718969314141445`*^9, 3.571897099304747*^9}, {3.571943165158436*^9, 
  3.5719431992843876`*^9}, {3.5719456443382363`*^9, 3.571945650354581*^9}}],

Cell["\<\
An example of automatic selection of the variable\[CloseCurlyQuote]s range in \
a 3D plot\
\>", "Text",
 CellChangeTimes->{{3.5719786654138756`*^9, 3.5719786896462617`*^9}}],

Cell[BoxData[
 RowBox[{"Plot3D", "[", 
  RowBox[{
   RowBox[{"Abs", "[", 
    RowBox[{"Gamma", "[", 
     RowBox[{"x", "+", 
      RowBox[{"I", " ", "y"}]}], "]"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{"-", "5"}], ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"y", ",", 
     RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{3.5719787438753633`*^9}],

Cell["\<\
Without tha AAS it would have been something like\
\>", "Text",
 CellChangeTimes->{{3.571978699517826*^9, 3.571978717575859*^9}}],

Cell[BoxData[
 RowBox[{"Plot3D", "[", 
  RowBox[{
   RowBox[{"Abs", "[", 
    RowBox[{"Gamma", "[", 
     RowBox[{"x", "+", 
      RowBox[{"I", " ", "y"}]}], "]"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{"-", "5"}], ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"y", ",", 
     RowBox[{"-", "1"}], ",", "1"}], "}"}], " ", ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.57197875308389*^9, 3.5719787634724846`*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Example 1", "Subsubsection",
 CellChangeTimes->{{3.5719416324827714`*^9, 3.571941640652239*^9}}],

Cell[TextData[{
 "Use of ",
 ButtonBox["WhenEvent",
  BaseStyle->"Hyperlink",
  ButtonData->{"ref/WhenEvent", None}],
 " to simulate a bouncing ball that retains 95 % of its velocity in each \
bounce "
}], "Text",
 CellChangeTimes->{{3.571898065299999*^9, 3.571898067522126*^9}, {
  3.5718981743872385`*^9, 3.57189819399436*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"NDSolve", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"y", "''"}], "[", "t", "]"}], "\[Equal]", 
       RowBox[{"-", "9.81"}]}], ",", 
      RowBox[{
       RowBox[{"y", "[", "0", "]"}], "\[Equal]", "5"}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{"y", "'"}], "[", "0", "]"}], "\[Equal]", "0"}], ",", 
      RowBox[{"WhenEvent", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"y", "[", "t", "]"}], "\[Equal]", "0"}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{"y", "'"}], "[", "t", "]"}], "->", 
         RowBox[{
          RowBox[{"-", "0.95"}], 
          RowBox[{
           RowBox[{"y", "'"}], "[", "t", "]"}]}]}]}], "]"}]}], "}"}], ",", 
    "y", ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", "10"}], "}"}]}], "]"}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", "t", "]"}], "/.", "%"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", "10"}], "}"}]}], "]"}]], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Example 2", "Subsubsection",
 CellChangeTimes->{{3.5719416324827714`*^9, 3.5719416570281754`*^9}}],

Cell["Integrating a function", "Text",
 CellChangeTimes->{{3.5718991738524046`*^9, 3.571899181061817*^9}}],

Cell[BoxData[
 RowBox[{"res", "=", 
  RowBox[{"Integrate", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"Sqrt", "[", "x", "]"}], 
     RowBox[{"Sqrt", "[", 
      RowBox[{"1", "+", "x"}], "]"}], 
     RowBox[{"Sqrt", "[", 
      RowBox[{"2", "+", "x"}], "]"}]}], ",", "x"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.571899292437187*^9, 3.571899293612254*^9}},
 CellID->24259],

Cell[TextData[{
 "you can represent the result in more traditional form (the form known in \
scientific literature and not made by ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " notation)"
}], "Text",
 CellChangeTimes->{{3.5718991863381186`*^9, 3.5718992305546474`*^9}, {
  3.571973350451374*^9, 3.5719733583068237`*^9}}],

Cell[BoxData[
 RowBox[{"TraditionalForm", "[", "res", "]"}]], "Input",
 CellChangeTimes->{{3.5703387972142086`*^9, 3.570338800109374*^9}, {
  3.571899297522478*^9, 3.5718993022467484`*^9}}],

Cell["\<\
Checking the simplified version of the derivative being correctly the \
integrand function\
\>", "Text",
 CellChangeTimes->{{3.5718992411432533`*^9, 3.57189926835781*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"D", "[", 
   RowBox[{"res", ",", "x"}], "]"}], "//", "FullSimplify"}]], "Input",
 CellChangeTimes->{{3.5677811605896845`*^9, 3.5677811660379963`*^9}, {
  3.571899305489934*^9, 3.571899316829582*^9}},
 CellID->226568681]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Example 3", "Subsubsection",
 CellChangeTimes->{{3.5719416324827714`*^9, 3.5719416652526455`*^9}}],

Cell["\<\
NIntegrate is optimized to work with highly oscillatory functions\
\>", "Text",
 CellChangeTimes->{{3.5677812181969795`*^9, 3.5677812478036733`*^9}, {
   3.571897126066278*^9, 3.5718971510237055`*^9}, 3.571897247420219*^9, 
   3.5718993224929066`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"fun", "=", 
   RowBox[{"\[Piecewise]", GridBox[{
      {
       FractionBox[
        RowBox[{"Sin", "[", 
         RowBox[{"10", " ", "x"}], "]"}], 
        SqrtBox[
         RowBox[{"-", "x"}]]], 
       RowBox[{
        RowBox[{"-", "\[Infinity]"}], "<", "x", "<", "0"}]},
      {
       FractionBox["1", 
        SqrtBox["x"]], 
       RowBox[{"0", "<", "x", "<", "1"}]},
      {
       RowBox[{
        RowBox[{"Sin", "[", 
         RowBox[{"2000", " ", "x"}], "]"}], " ", 
        SuperscriptBox["x", "2"]}], 
       RowBox[{"1", "<", "x", "<", "2"}]},
      {
       FractionBox[
        RowBox[{"Cos", "[", 
         RowBox[{"2", " ", "x"}], "]"}], "x"], 
       RowBox[{"2", "<", "x", "<", "\[Infinity]"}]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxItemSize->{
      "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.84]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}]}]}], ";"}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.5677812516678944`*^9, 3.567781251873906*^9}}],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{"fun", ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{"-", "5"}], ",", "5"}], "}"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"NIntegrate", "[", 
  RowBox[{"fun", ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"Sin", "[", 
    FractionBox["1", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"5", "x"}], "-", "1"}], ")"}], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"5", "x"}], "-", "2"}], ")"}], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"5", "x"}], "-", "3"}], ")"}]}]], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.567781318079693*^9, 3.5677813185287185`*^9}}],

Cell[BoxData[
 RowBox[{"NIntegrate", "[", 
  RowBox[{
   RowBox[{"Sin", "[", 
    FractionBox["1", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"5", "x"}], "-", "1"}], ")"}], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"5", "x"}], "-", "2"}], ")"}], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"5", "x"}], "-", "3"}], ")"}]}]], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.567781318079693*^9, 3.567781324064035*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Example 4", "Subsubsection",
 CellChangeTimes->{{3.5719416324827714`*^9, 3.571941640652239*^9}, 
   3.5719416799674873`*^9}],

Cell["\<\
Adding assumptions in order to make the solution faster and more accurate \
according to conditions we know about our problem, variables and parameters\
\>", "Text",
 CellChangeTimes->{{3.571899889053312*^9, 3.571899919482052*^9}}],

Cell[BoxData[
 RowBox[{"Remove", "[", "\"\<Global`*\>\"", "]"}]], "Input",
 CellChangeTimes->{{3.5719007449782677`*^9, 3.57190079222197*^9}, {
  3.57197321033136*^9, 3.571973215305644*^9}}],

Cell[BoxData[
 RowBox[{"Integrate", "[", 
  RowBox[{
   RowBox[{"Abs", "[", 
    RowBox[{"2", "-", 
     RowBox[{"Abs", "[", "x", "]"}]}], "]"}], ",", "x"}], "]"}]], "Input",
 CellChangeTimes->{{3.571900902050252*^9, 3.571900919769265*^9}, 
   3.571901082253559*^9}],

Cell[BoxData[
 RowBox[{"Integrate", "[", 
  RowBox[{
   RowBox[{"Abs", "[", 
    RowBox[{"2", "-", 
     RowBox[{"Abs", "[", "x", "]"}]}], "]"}], ",", "x", ",", 
   RowBox[{"Assumptions", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"x", "\[Element]", "Reals"}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.571900902050252*^9, 3.5719010385030565`*^9}, {
  3.571901074217099*^9, 3.5719010758961954`*^9}}],

Cell["\<\
Assumptions is a local option accepted by almost any macro function dealing \
with symbolic methods. When you need to set an assumption for more than one \
calculation, it\[CloseCurlyQuote]s better if you set a global assumption. \
There two alternatives: using the wrapper Assuming or the global variable \
$Assumptions\
\>", "Text",
 CellChangeTimes->{{3.571901105757903*^9, 3.571901160092011*^9}, {
  3.571901217833314*^9, 3.571901270371319*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"Limit", "[", 
    RowBox[{
     RowBox[{"x", "^", "a"}], ",", 
     RowBox[{"x", "\[Rule]", "Infinity"}]}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"Series", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Min", "[", 
        RowBox[{
         RowBox[{"x", "^", "2"}], ",", 
         RowBox[{"1", "+", "a"}]}], "]"}], 
       RowBox[{"Cos", "[", "x", "]"}]}], "+", 
      RowBox[{"Sin", "[", "x", "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "0", ",", "2"}], "}"}]}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"Refine", "[", 
    RowBox[{"Sqrt", "[", 
     RowBox[{"a", "^", "2"}], "]"}], "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"Integrate", "[", 
    RowBox[{
     RowBox[{"x", "^", "a"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}]}], 
  "\[IndentingNewLine]", "}"}]], "Input"],

Cell[BoxData[
 RowBox[{"Assuming", "[", 
  RowBox[{
   RowBox[{"a", ">", "0"}], ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Limit", "[", 
      RowBox[{
       RowBox[{"x", "^", "a"}], ",", 
       RowBox[{"x", "\[Rule]", "Infinity"}]}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Series", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"Min", "[", 
          RowBox[{
           RowBox[{"x", "^", "2"}], ",", 
           RowBox[{"1", "+", "a"}]}], "]"}], 
         RowBox[{"Cos", "[", "x", "]"}]}], "+", 
        RowBox[{"Sin", "[", "x", "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "0", ",", "2"}], "}"}]}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Refine", "[", 
      RowBox[{"Sqrt", "[", 
       RowBox[{"a", "^", "2"}], "]"}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Integrate", "[", 
      RowBox[{
       RowBox[{"x", "^", "a"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}]}], 
    "\[IndentingNewLine]", "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5719013114726696`*^9, 3.571901331485814*^9}}],

Cell[BoxData[
 RowBox[{"$Assumptions", "=", 
  RowBox[{"{", 
   RowBox[{"a", ">", "0"}], "}"}]}]], "Input",
 CellChangeTimes->{{3.571901356311234*^9, 3.571901364789719*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"Limit", "[", 
    RowBox[{
     RowBox[{"x", "^", "a"}], ",", 
     RowBox[{"x", "\[Rule]", "Infinity"}]}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"Series", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Min", "[", 
        RowBox[{
         RowBox[{"x", "^", "2"}], ",", 
         RowBox[{"1", "+", "a"}]}], "]"}], 
       RowBox[{"Cos", "[", "x", "]"}]}], "+", 
      RowBox[{"Sin", "[", "x", "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "0", ",", "2"}], "}"}]}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"Refine", "[", 
    RowBox[{"Sqrt", "[", 
     RowBox[{"a", "^", "2"}], "]"}], "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"Integrate", "[", 
    RowBox[{
     RowBox[{"x", "^", "a"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}]}], 
  "\[IndentingNewLine]", "}"}]], "Input"],

Cell["\<\
In many cases, in particular for complex calculations, using assumptions can \
make the difference both in obtaining the right solution and obtaining it in \
a shorter time\
\>", "Text",
 CellChangeTimes->{{3.571901417419729*^9, 3.5719014834795074`*^9}}],

Cell[BoxData[
 RowBox[{"$Assumptions", "=."}]], "Input",
 CellChangeTimes->{{3.5719014865756845`*^9, 3.571901489774868*^9}}],

Cell[BoxData[
 RowBox[{"AbsoluteTiming", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Limit", "[", 
     RowBox[{
      RowBox[{"x", "^", "a"}], ",", 
      RowBox[{"x", "\[Rule]", "Infinity"}]}], "]"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"Series", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"Min", "[", 
         RowBox[{
          RowBox[{"x", "^", "2"}], ",", 
          RowBox[{"1", "+", "a"}]}], "]"}], 
        RowBox[{"Cos", "[", "x", "]"}]}], "+", 
       RowBox[{"Sin", "[", "x", "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", "0", ",", "2"}], "}"}]}], "]"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"Refine", "[", 
     RowBox[{"Sqrt", "[", 
      RowBox[{"a", "^", "2"}], "]"}], "]"}], ",", "\[IndentingNewLine]", 
    RowBox[{"Integrate", "[", 
     RowBox[{
      RowBox[{"x", "^", "a"}], ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}]}], "}"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.5719014960932293`*^9, 3.5719015025996013`*^9}}],

Cell[BoxData[
 RowBox[{"$Assumptions", "=", 
  RowBox[{"{", 
   RowBox[{"a", ">", "0"}], "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"AbsoluteTiming", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Limit", "[", 
     RowBox[{
      RowBox[{"x", "^", "a"}], ",", 
      RowBox[{"x", "\[Rule]", "Infinity"}]}], "]"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"Series", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"Min", "[", 
         RowBox[{
          RowBox[{"x", "^", "2"}], ",", 
          RowBox[{"1", "+", "a"}]}], "]"}], 
        RowBox[{"Cos", "[", "x", "]"}]}], "+", 
       RowBox[{"Sin", "[", "x", "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", "0", ",", "2"}], "}"}]}], "]"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"Refine", "[", 
     RowBox[{"Sqrt", "[", 
      RowBox[{"a", "^", "2"}], "]"}], "]"}], ",", "\[IndentingNewLine]", 
    RowBox[{"Integrate", "[", 
     RowBox[{
      RowBox[{"x", "^", "a"}], ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}]}], "}"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.5719014960932293`*^9, 3.571901505923792*^9}}]
}, Open  ]]
}, Open  ]]
},
ScreenStyleEnvironment->"SlideShow",
WindowSize->{1158, 715},
WindowMargins->{{61, Automatic}, {Automatic, 8}},
FrontEndVersion->"9.0 for Microsoft Windows (64-bit) (January 25, 2013)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "SlideShowHeader"->{
  Cell[579, 22, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[4423, 127, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[6069, 188, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[7762, 245, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[11116, 360, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"SlideShowHeader", 19056, 609}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[579, 22, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[668, 27, 463, 10, 81, "Subsection"],
Cell[1134, 39, 2000, 40, 347, "Text"],
Cell[3137, 81, 183, 4, 45, "Text"],
Cell[3323, 87, 414, 13, 46, "Input"],
Cell[3740, 102, 139, 3, 45, "Text"],
Cell[3882, 107, 492, 14, 46, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[4423, 127, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[4512, 132, 102, 1, 50, "Subsubsection"],
Cell[4617, 135, 329, 9, 45, "Text"],
Cell[4949, 146, 873, 28, 31, "Input"],
Cell[5825, 176, 195, 6, 31, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[6069, 188, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[6158, 193, 104, 1, 34, "Subsubsection"],
Cell[6265, 196, 106, 1, 30, "Text"],
Cell[6374, 199, 374, 11, 31, "Input",
 CellID->24259],
Cell[6751, 212, 329, 8, 76, "Text"],
Cell[7083, 222, 189, 3, 46, "Input"],
Cell[7275, 227, 181, 4, 30, "Text"],
Cell[7459, 233, 254, 6, 31, "Input",
 CellID->226568681]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[7762, 245, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[7851, 250, 104, 1, 34, "Subsubsection"],
Cell[7958, 253, 261, 5, 30, "Text"],
Cell[8222, 260, 1437, 42, 109, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[9662, 304, 162, 5, 31, "Input"],
Cell[9827, 311, 182, 5, 31, "Input"],
Cell[10012, 318, 524, 17, 48, "Input"],
Cell[10539, 337, 528, 17, 48, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[11116, 360, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[11205, 365, 130, 2, 34, "Subsubsection"],
Cell[11338, 369, 241, 4, 30, "Text"],
Cell[11582, 375, 189, 3, 31, "Input"],
Cell[11774, 380, 266, 7, 31, "Input"],
Cell[12043, 389, 407, 10, 31, "Input"],
Cell[12453, 401, 459, 8, 49, "Text"],
Cell[12915, 411, 925, 29, 112, "Input"],
Cell[13843, 442, 1155, 33, 132, "Input"],
Cell[15001, 477, 173, 4, 31, "Input"],
Cell[15177, 483, 925, 29, 112, "Input"],
Cell[16105, 514, 264, 5, 30, "Text"],
Cell[16372, 521, 124, 2, 31, "Input"],
Cell[16499, 525, 1040, 31, 92, "Input"],
Cell[17542, 558, 107, 3, 31, "Input"],
Cell[17652, 563, 1038, 31, 92, "Input"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
