(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 9.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[     27664,        840]
NotebookOptionsPosition[     22558,        693]
NotebookOutlinePosition[     23521,        725]
CellTagsIndexPosition[     23443,        720]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " as a programming language"
}], "Subsection",
 CellChangeTimes->{
  3.5677576479117575`*^9, {3.56775769201528*^9, 3.567757695118458*^9}, 
   3.567779814134672*^9, {3.5677804469578676`*^9, 3.5677804508440895`*^9}, 
   3.5677823057721853`*^9, 3.56782322662325*^9, {3.5718961387628074`*^9, 
   3.571896154354699*^9}, {3.5718966008042345`*^9, 3.571896612203887*^9}, {
   3.571930687097309*^9, 3.5719306902173147`*^9}}],

Cell[TextData[{
 "There are many different examples of ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " programming language and, frankly, many things should be discussed when \
considering the ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " language.\nJust to give you an idea of what is in the pipe, here is a blog \
article posted by Stephen Wolfram: ",
 ButtonBox["What Should We Call the Language of Mathematica?",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://blog.stephenwolfram.com/2013/02/what-should-we-call-the-\
language-of-mathematica/"], None},
  ButtonNote->
   "http://blog.stephenwolfram.com/2013/02/what-should-we-call-the-language-\
of-mathematica/"]
}], "Text",
 CellChangeTimes->{{3.571936728450277*^9, 3.5719368270529165`*^9}, {
  3.5719370105684133`*^9, 3.571937082279515*^9}, {3.5719409383520694`*^9, 
  3.5719409398041525`*^9}}],

Cell[TextData[{
 "In order to introduce the subject, we can consider the basic concept of \
programming: ",
 StyleBox["a computer program, or just a program, is a sequence of \
instructions written to perform a specified task with a computer",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 " (from ",
 ButtonBox["Wikipedia",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://en.wikipedia.org/wiki/Computer_program"], None},
  ButtonNote->"http://en.wikipedia.org/wiki/Computer_program"],
 ")."
}], "Text",
 CellChangeTimes->{{3.571937710113425*^9, 3.57193774447239*^9}, {
  3.571937790477021*^9, 3.571937835879618*^9}, {3.571941089855735*^9, 
  3.571941152378311*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell[TextData[{
 "The basic principles of ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " language"
}], "Subsubsection",
 CellChangeTimes->{{3.5719378483673325`*^9, 3.5719378737417836`*^9}, {
  3.57197495759045*^9, 3.5719749680112677`*^9}}],

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " is a functional and symbolic language. These two features make easier \
maximizing code modularity, analyzability and testability."
}], "Text",
 CellChangeTimes->{{3.5719749710220737`*^9, 3.5719749860605*^9}, {
  3.5719750413702655`*^9, 3.5719750595703063`*^9}, {3.5719791442112617`*^9, 
  3.5719791462573786`*^9}}],

Cell["\<\
The founding principle: everything is an expression\
\>", "Text",
 CellChangeTimes->{{3.5719750906910863`*^9, 3.5719751013956985`*^9}, {
  3.5719791597531505`*^9, 3.5719791676085997`*^9}}],

Cell[BoxData[
 RowBox[{"1", "/", "3"}]], "Input",
 CellChangeTimes->{{3.569665173904052*^9, 3.569665174624093*^9}}],

Cell[BoxData[
 RowBox[{"FullForm", "[", 
  FractionBox["1", "3"], "]"}]], "Input",
 CellChangeTimes->{{3.40427652334375*^9, 3.404276529328125*^9}, {
  3.4167180995*^9, 3.41671810125*^9}}],

Cell[BoxData[
 RowBox[{"TreeForm", "[", 
  FractionBox["1", "3"], "]"}]], "Input",
 CellChangeTimes->{{3.40427653175*^9, 3.404276536875*^9}, {
  3.416718105828125*^9, 3.416718106609375*^9}}],

Cell[BoxData[
 RowBox[{"FullForm", "[", 
  RowBox[{
   RowBox[{"x", "^", "3"}], "+", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "+", 
       RowBox[{"x", " ", "y"}]}], ")"}], "^", "2"}], "a"]}], "]"}]], "Input",
 CellChangeTimes->{{3.5719824036252832`*^9, 3.5719824103946705`*^9}}],

Cell[BoxData[
 RowBox[{"TreeForm", "[", 
  RowBox[{
   RowBox[{"x", "^", "3"}], "+", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "+", 
       RowBox[{"x", " ", "y"}]}], ")"}], "^", "2"}], "a"]}], "]"}]], "Input",
 CellChangeTimes->{{3.5719824215853105`*^9, 3.5719824266716013`*^9}}],

Cell["\<\
graphics objects are also internally represented with the same symbolic \
structure\
\>", "Text",
 CellChangeTimes->{{3.43015602784375*^9, 3.430156031953125*^9}, {
  3.4366522526875*^9, 3.43665225390625*^9}, {3.5719751268451543`*^9, 
  3.5719751420380235`*^9}, {3.571982433417987*^9, 3.5719824482498355`*^9}}],

Cell[BoxData[
 RowBox[{"gr", "=", 
  RowBox[{"Graphics", "[", 
   RowBox[{"{", 
    RowBox[{"Blue", ",", " ", 
     RowBox[{"Circle", "[", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0"}], "}"}], "]"}]}], "}"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.404276540609375*^9, 3.4042765531875*^9}, {
  3.4058323299375*^9, 3.4058323344375*^9}}],

Cell[BoxData[
 RowBox[{"FullForm", "[", "gr", "]"}]], "Input",
 CellChangeTimes->{{3.43015603925*^9, 3.430156044015625*^9}}],

Cell[BoxData[
 RowBox[{"TreeForm", "[", "gr", "]"}]], "Input",
 CellChangeTimes->{{3.404276555109375*^9, 3.40427655740625*^9}}],

Cell["and even an interface objects", "Text",
 CellChangeTimes->{{3.571975145901244*^9, 3.5719751680005083`*^9}}],

Cell[BoxData[
 RowBox[{"obj", "=", 
  RowBox[{"PopupMenu", "[", 
   RowBox[{
    RowBox[{"Dynamic", "[", "var", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"val1", ",", "val2", ",", "val2"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5719752109799666`*^9, 3.571975212999082*^9}}],

Cell[BoxData[
 RowBox[{"TreeForm", "[", "obj", "]"}]], "Input",
 CellChangeTimes->{{3.571975157821926*^9, 3.571975218405391*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell[TextData[{
 "The basic principles of ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " language"
}], "Subsubsection",
 CellChangeTimes->{{3.5719378483673325`*^9, 3.5719378737417836`*^9}, {
  3.57197495759045*^9, 3.5719749680112677`*^9}}],

Cell["\<\
The most important conseguence of symbolic expression representation is that \
everything can be managed at the same way, just using expression manipulation \
commands, like Cases, Apply, Replace, Map, etc.\
\>", "Text",
 CellChangeTimes->{{3.5719749710220737`*^9, 3.5719749860605*^9}, {
  3.5719750413702655`*^9, 3.5719750595703063`*^9}, {3.571975244045858*^9, 
  3.5719752917785883`*^9}}],

Cell["\<\
Given an algebraic expression how to replace an each occurance of the \
variabile x with a different random integer number\
\>", "Text",
 CellChangeTimes->{{3.571982614525346*^9, 3.571982626045005*^9}, {
  3.5719826976330996`*^9, 3.571982702505378*^9}, {3.5719827673430862`*^9, 
  3.5719827864061766`*^9}, {3.571982835050959*^9, 3.571982869282917*^9}}],

Cell[BoxData[
 RowBox[{"ReplaceAll", "[", " ", 
  RowBox[{
   RowBox[{
    SuperscriptBox["x", "3"], "+", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "+", "z"}], ")"}], 
     RowBox[{"2", "x"}]]}], ",", 
   RowBox[{"x", "\[RuleDelayed]", 
    RowBox[{"RandomInteger", "[", 
     RowBox[{"{", 
      RowBox[{"1", ",", "10"}], "}"}], "]"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.571982630062235*^9, 3.571982662726103*^9}, {
  3.5719827067136188`*^9, 3.5719827488100266`*^9}}],

Cell[BoxData[
 RowBox[{"ReplaceAll", "[", " ", 
  RowBox[{
   RowBox[{
    SuperscriptBox["x", "3"], "+", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "+", "z"}], ")"}], 
     RowBox[{"2", "x"}]]}], ",", 
   RowBox[{"x", "->", 
    RowBox[{"RandomInteger", "[", 
     RowBox[{"{", 
      RowBox[{"1", ",", "10"}], "}"}], "]"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.571982630062235*^9, 3.571982662726103*^9}, {
  3.5719827067136188`*^9, 3.5719827488100266`*^9}, {3.5719842658836803`*^9, 
  3.5719842710709767`*^9}}],

Cell["\<\
A different notation (infix) for ReplaceAll\
\>", "Text",
 CellChangeTimes->{{3.57198432707118*^9, 3.5719843345646086`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox["x", "3"], "+", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"1", "+", "z"}], ")"}], 
    RowBox[{"2", "x"}]]}], "/.", 
  RowBox[{"x", "->", 
   RowBox[{"RandomInteger", "[", 
    RowBox[{"{", 
     RowBox[{"1", ",", "10"}], "}"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.571984307794077*^9, 3.571984308302106*^9}, 
   3.5719843410219774`*^9}],

Cell["How to reverse the x-axes in a standard plot", "Text",
 CellChangeTimes->{{3.571975301196127*^9, 3.57197531069267*^9}, {
  3.5719793140759773`*^9, 3.5719793217494164`*^9}}],

Cell[BoxData[
 RowBox[{"s", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"Cos", "[", "x", "]"}], "+", "x"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "0", ",", "10"}], "}"}]}], "]"}]}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10002.},
 CellChangeTimes->{
  3.480404505984375*^9, 3.5280050880824075`*^9, {3.5719793965836964`*^9, 
   3.5719793983807993`*^9}}],

Cell["\<\
just manage on its internal symbolic expression (FullGraphics takes a \
graphics object, and generates a new one in which objects specified by \
graphics options are given as explicit lists of graphics primitives)\
\>", "Text",
 CellChangeTimes->{{3.571975319874195*^9, 3.57197532713161*^9}, {
  3.5719793039383974`*^9, 3.5719793051124644`*^9}, {3.5719794005889254`*^9, 
  3.5719794107825084`*^9}}],

Cell[BoxData[
 RowBox[{"ReplaceAll", "[", 
  RowBox[{
   RowBox[{"FullGraphics", "[", "s", "]"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"x_Real", ",", "y_Real"}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "x"}], ",", "y"}], "}"}]}]}], "]"}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10002.},
 CellChangeTimes->{
  3.480404505984375*^9, 3.5280050880824075`*^9, {3.571979413997692*^9, 
   3.571979421970148*^9}}],

Cell[TextData[{
 "How to count frequencies in a list of repeated graphics objects: the same \
way as we count frequencies of numbers or any other symbolic expression, \
using ",
 ButtonBox["Tally",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Tally"]
}], "Text",
 CellChangeTimes->{{3.571975383651843*^9, 3.571975414309596*^9}, {
  3.5719794645895863`*^9, 3.571979464596586*^9}}],

Cell[BoxData[
 RowBox[{"s1", "=", 
  RowBox[{"Graphics3D", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"Red", ",", 
      RowBox[{"Sphere", "[", "]"}]}], "}"}], ",", 
    RowBox[{"ImageSize", "\[Rule]", "50"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5719754456233873`*^9, 3.571975469159734*^9}}],

Cell[BoxData[
 RowBox[{"s2", "=", 
  RowBox[{"Graphics3D", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"Blue", ",", 
      RowBox[{"Sphere", "[", "]"}]}], "}"}], ",", 
    RowBox[{"ImageSize", "\[Rule]", "50"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5719754456233873`*^9, 3.5719754755731*^9}}],

Cell[BoxData[
 RowBox[{"s3", "=", 
  RowBox[{"Graphics3D", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"Yellow", ",", 
      RowBox[{"Sphere", "[", "]"}]}], "}"}], ",", 
    RowBox[{"ImageSize", "\[Rule]", "50"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5719754781402473`*^9, 3.5719754857066803`*^9}}],

Cell[BoxData[
 RowBox[{"data", "=", 
  RowBox[{"RandomChoice", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"s1", ",", "s2", ",", "s3"}], "}"}], ",", "50"}], 
   "]"}]}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10003.},
 CellChangeTimes->{
  3.48040238309375*^9, 3.48040453475*^9, 3.5280051781625595`*^9, {
   3.5719754186598454`*^9, 3.5719754280693836`*^9}, {3.5719754911459913`*^9, 
   3.5719754982293963`*^9}}],

Cell[BoxData[
 RowBox[{"Tally", "[", "data", "]"}]], "Input",
 CellChangeTimes->{{3.5719754307985396`*^9, 3.571975431296568*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell[TextData[{
 "The basic principles of ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " language"
}], "Subsubsection",
 CellChangeTimes->{{3.5719378483673325`*^9, 3.5719378737417836`*^9}, {
  3.57197495759045*^9, 3.5719749680112677`*^9}}],

Cell["\<\
Function languages have some basic constructs that allow to apply function to \
data set in a very easy and intuitive way.
Here is an example of attribute Listable and then another about Apply\
\>", "Text",
 CellChangeTimes->{{3.571975642435644*^9, 3.571975717937963*^9}}],

Cell[CellGroupData[{

Cell["\<\
Calculate a trigonometric function on a list of elements\
\>", "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.5280120065127897`*^9, 3.528012021910017*^9}, 
   3.5280123366093693`*^9, {3.5719757357889843`*^9, 3.57197574550554*^9}}],

Cell[BoxData[
 RowBox[{"Attributes", "[", "Sin", "]"}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.528012272540057*^9, 3.5280122831168756`*^9}, 
   3.5280123366093693`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"a", "=", 
   RowBox[{"RandomReal", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "100"}], "}"}], ",", 
     RowBox[{"{", "100000", "}"}]}], "]"}]}], ";"}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.528012024920822*^9, 3.5280120498184657`*^9}, {
   3.528012150111042*^9, 3.528012150251442*^9}, {3.5280122030107346`*^9, 
   3.5280122257867746`*^9}, 3.5280123366093693`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"procedural", " ", "approach"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"res", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"Sin", "[", 
       RowBox[{"a", "[", 
        RowBox[{"[", "i", "]"}], "]"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", 
        RowBox[{"Length", "[", "a", "]"}]}], "}"}]}], "]"}]}], 
   ";"}]}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.528012059599683*^9, 3.528012078428916*^9}, {
   3.528012155961052*^9, 3.528012158020256*^9}, 3.5280123366093693`*^9, {
   3.571975751749897*^9, 3.5719757562511544`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"using", " ", "Listable"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"res1", "=", 
    RowBox[{"Sin", "[", "a", "]"}]}], ";"}]}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.528012081439721*^9, 3.5280120939977436`*^9}, {
   3.528012159923459*^9, 3.528012162544264*^9}, 3.5280123366093693`*^9, {
   3.5719757602923856`*^9, 3.5719757641376057`*^9}}],

Cell[BoxData[
 RowBox[{"res", "===", "res1"}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.5280121636518655`*^9, 3.5280121657422695`*^9}, 
   3.5280123366093693`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Calculate the sum of elements in a list\
\>", "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10001.},
 CellChangeTimes->{{3.5280123416637783`*^9, 3.528012350586994*^9}, 
   3.5280125235600977`*^9, {3.5719757748402176`*^9, 3.571975783956739*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"a", "=", 
   RowBox[{"RandomReal", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "100"}], "}"}], ",", 
     RowBox[{"{", "100000", "}"}]}], "]"}]}], ";"}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10001.},
 CellChangeTimes->{3.528012364034218*^9, 3.5280125235600977`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"procedural", " ", "approach"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"res", "=", "0"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"res", "=", 
       RowBox[{"res", "+", 
        RowBox[{"a", "[", 
         RowBox[{"[", "i", "]"}], "]"}]}]}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", 
        RowBox[{"Length", "[", "a", "]"}]}], "}"}]}], "]"}], 
    ";"}]}]}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10001.},
 CellChangeTimes->{{3.528012059599683*^9, 3.528012078428916*^9}, {
   3.528012155961052*^9, 3.528012158020256*^9}, 3.5280123366093693`*^9, {
   3.5280123759370384`*^9, 3.5280123889006615`*^9}, 3.5280125235600977`*^9, {
   3.5719757868689055`*^9, 3.5719757938363037`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"functional", " ", "approach"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"res1", "=", 
    RowBox[{"Apply", "[", 
     RowBox[{"Plus", ",", "a"}], "]"}]}], ";"}]}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10001.},
 CellChangeTimes->{{3.528012081439721*^9, 3.5280120939977436`*^9}, {
   3.528012159923459*^9, 3.528012162544264*^9}, 3.5280123366093693`*^9, {
   3.528012400257481*^9, 3.5280124414103537`*^9}, 3.5280125235600977`*^9, {
   3.5719757970224867`*^9, 3.571975803224841*^9}}],

Cell[BoxData["res"], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10001.},
 CellChangeTimes->{{3.528012462891591*^9, 3.5280124631567917`*^9}, 
   3.5280125235600977`*^9}],

Cell[BoxData["res1"], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10001.},
 CellChangeTimes->{{3.5280124646699944`*^9, 3.5280124651847954`*^9}, 
   3.5280125235600977`*^9}],

Cell["Check about time required", "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10001.},
 CellChangeTimes->{{3.5280124994112554`*^9, 3.5280125235600977`*^9}, {
  3.571975806899051*^9, 3.5719758119153385`*^9}}],

Cell[BoxData[
 RowBox[{"AbsoluteTiming", "[", 
  RowBox[{
   RowBox[{"res1", "=", 
    RowBox[{"Apply", "[", 
     RowBox[{"Plus", ",", "a"}], "]"}]}], ";"}], "]"}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10001.},
 CellChangeTimes->{3.5280125235600977`*^9}],

Cell[BoxData[
 RowBox[{"AbsoluteTiming", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"res", "=", "0"}], ";", "\[IndentingNewLine]", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"res", "=", 
      RowBox[{"res", "+", 
       RowBox[{"a", "[", 
        RowBox[{"[", "i", "]"}], "]"}]}]}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", 
       RowBox[{"Length", "[", "a", "]"}]}], "}"}]}], "]"}], ";"}], 
  "]"}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10001.},
 CellChangeTimes->{{3.5280124285715313`*^9, 3.5280124330487385`*^9}, 
   3.5280125235600977`*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Example 1", "Subsubsection",
 CellChangeTimes->{{3.5719378483673325`*^9, 3.5719378516035175`*^9}}],

Cell["\<\
We do program even when we do something really easy like to intercept \
numerical points used by NIntegrate during the numerical integration:\
\>", "Text",
 CellChangeTimes->{{3.571938556020808*^9, 3.571938568800539*^9}, {
   3.57193975140318*^9, 3.5719397973428073`*^9}, {3.5719411589656878`*^9, 
   3.571941173218503*^9}, 3.571979569667596*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"points", "=", " ", 
   RowBox[{"Reap", "[", 
    RowBox[{"NIntegrate", "[", 
     RowBox[{
      RowBox[{"1", "/", 
       RowBox[{"Sqrt", "[", "x", "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", 
        RowBox[{"-", "1"}], ",", "0", ",", "1"}], "}"}], ",", 
      RowBox[{"EvaluationMonitor", ":>", 
       RowBox[{"Sow", "[", "x", "]"}]}]}], "]"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.571939805939299*^9, 3.5719398155588493`*^9}}],

Cell[BoxData[
 RowBox[{"ListPlot", "[", 
  RowBox[{
   RowBox[{"points", "[", 
    RowBox[{"[", 
     RowBox[{"2", ",", "1"}], "]"}], "]"}], ",", 
   RowBox[{"PlotRange", "->", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.571938570436632*^9, 3.571938576763994*^9}, {
  3.5719397999299555`*^9, 3.5719398202151155`*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Example 2", "Subsubsection",
 CellChangeTimes->{{3.5719378483673325`*^9, 3.5719378516035175`*^9}, 
   3.5719412860129547`*^9}],

Cell[TextData[{
 "Another example of programming: importing a table of data from a ",
 ButtonBox["web site",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www.bls.gov/web/laumstrk.htm"], None},
  ButtonNote->"http://www.bls.gov/web/laumstrk.htm"],
 " and generate a table in the notebook"
}], "Text",
 CellChangeTimes->{{3.571937939484544*^9, 3.5719379639779453`*^9}, {
  3.5719380404643197`*^9, 3.5719380494888363`*^9}, {3.5719411825650377`*^9, 
  3.57194118872439*^9}, {3.57197582505609*^9, 3.571975835230672*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"data", "=", 
    RowBox[{"Import", "[", 
     RowBox[{"\"\<http://www.bls.gov/web/laumstrk.htm\>\"", ",", 
      RowBox[{"{", "\"\<Data\>\"", "}"}]}], "]"}]}], ";"}], " "}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"data", "=", 
    RowBox[{"Cases", "[", 
     RowBox[{"data", ",", 
      RowBox[{"{", 
       RowBox[{"_Integer", ",", "_String", ",", "_Real"}], "}"}], ",", 
      "Infinity"}], "]"}]}], ";"}], "  "}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"results", "=", 
    RowBox[{"data", "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "3"}], "}"}]}], "]"}], "]"}]}], ";"}], " "}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"SortBy", "[", 
    RowBox[{"results", ",", "First"}], "]"}], ";"}], " "}], "\n", 
 RowBox[{
  RowBox[{"Grid", "[", 
   RowBox[{"results", ",", 
    RowBox[{"Alignment", "\[Rule]", "Left"}], ",", 
    RowBox[{"Frame", "\[Rule]", "All"}], ",", 
    RowBox[{"Background", "\[Rule]", "LightYellow"}], ",", 
    RowBox[{"BaseStyle", "\[Rule]", 
     RowBox[{"{", "\"\<Menu\>\"", "}"}]}]}], "]"}], " "}]}], "Input",
 CellChangeTimes->{{3.5719379700062895`*^9, 3.571937998240905*^9}, 
   3.571938072871173*^9, 3.5719381297864285`*^9}]
}, Open  ]],

Cell["One-line functional code", "Subsubsection",
 CellChangeTimes->{{3.5719829354837036`*^9, 3.5719829443262095`*^9}}]
}, Open  ]]
},
ScreenStyleEnvironment->"SlideShow",
WindowSize->{958, 709},
WindowMargins->{{178, Automatic}, {Automatic, -9}},
FrontEndVersion->"9.0 for Microsoft Windows (64-bit) (January 25, 2013)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "SlideShowHeader"->{
  Cell[579, 22, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[2768, 85, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[6321, 200, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[12387, 387, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[18977, 583, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[20400, 628, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"SlideShowHeader", 22897, 704}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[579, 22, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[668, 27, 481, 10, 81, "Subsection"],
Cell[1152, 39, 878, 21, 167, "Text"],
Cell[2033, 62, 686, 17, 137, "Text"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2768, 85, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[2857, 90, 247, 7, 50, "Subsubsection"],
Cell[3107, 99, 383, 8, 76, "Text"],
Cell[3493, 109, 198, 4, 45, "Text"],
Cell[3694, 115, 115, 2, 46, "Input"],
Cell[3812, 119, 187, 4, 73, "Input"],
Cell[4002, 125, 190, 4, 73, "Input"],
Cell[4195, 131, 306, 9, 73, "Input"],
Cell[4504, 142, 306, 9, 73, "Input"],
Cell[4813, 153, 319, 6, 75, "Text"],
Cell[5135, 161, 342, 9, 46, "Input"],
Cell[5480, 172, 124, 2, 46, "Input"],
Cell[5607, 176, 127, 2, 46, "Input"],
Cell[5737, 180, 113, 1, 45, "Text"],
Cell[5853, 183, 287, 7, 46, "Input"],
Cell[6143, 192, 129, 2, 46, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[6321, 200, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[6410, 205, 247, 7, 50, "Subsubsection"],
Cell[6660, 214, 400, 7, 105, "Text"],
Cell[7063, 223, 362, 6, 75, "Text"],
Cell[7428, 231, 493, 14, 51, "Input"],
Cell[7924, 247, 534, 15, 51, "Input"],
Cell[8461, 264, 134, 3, 45, "Text"],
Cell[8598, 269, 405, 13, 48, "Input"],
Cell[9006, 284, 178, 2, 45, "Text"],
Cell[9187, 288, 400, 11, 46, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10002.}],
Cell[9590, 301, 408, 7, 105, "Text"],
Cell[10001, 310, 462, 13, 46, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10002.}],
Cell[10466, 325, 381, 9, 105, "Text"],
Cell[10850, 336, 304, 8, 46, "Input"],
Cell[11157, 346, 303, 8, 46, "Input"],
Cell[11463, 356, 309, 8, 46, "Input"],
Cell[11775, 366, 431, 11, 46, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10003.}],
Cell[12209, 379, 129, 2, 46, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[12387, 387, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[12476, 392, 247, 7, 50, "Subsubsection"],
Cell[12726, 401, 282, 5, 105, "Text"],
Cell[CellGroupData[{
Cell[13033, 410, 276, 5, 45, "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[13312, 417, 214, 4, 46, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[13529, 423, 465, 11, 46, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[13997, 436, 698, 19, 76, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[14698, 457, 463, 10, 76, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[15164, 469, 207, 4, 46, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}]
}, Open  ]],
Cell[CellGroupData[{
Cell[15408, 478, 260, 5, 45, "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10001.}],
Cell[15671, 485, 335, 9, 46, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10001.}],
Cell[16009, 496, 868, 23, 105, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10001.}],
Cell[16880, 521, 576, 13, 76, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10001.}],
Cell[17459, 536, 178, 3, 46, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10001.}],
Cell[17640, 541, 181, 3, 46, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10001.}],
Cell[17824, 546, 215, 3, 45, "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10001.}],
Cell[18042, 551, 272, 7, 46, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10001.}],
Cell[18317, 560, 599, 16, 105, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10001.}]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[18977, 583, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[19066, 588, 104, 1, 50, "Subsubsection"],
Cell[19173, 591, 356, 6, 75, "Text"],
Cell[19532, 599, 493, 13, 76, "Input"],
Cell[20028, 614, 323, 8, 46, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[20400, 628, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[20489, 633, 132, 2, 50, "Subsubsection"],
Cell[20624, 637, 528, 11, 75, "Text"],
Cell[21155, 650, 1253, 36, 192, "Input"]
}, Open  ]],
Cell[22423, 689, 119, 1, 50, "Subsubsection"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
